%global git_tag %{version}

Name:           eclipse-recommenders
Version:        2.5.1
Release:        2%{?dist}
Summary:        Eclipse Code Recommenders
License:        EPL
URL:            https://www.eclipse.org/recommenders/

Source0:        http://git.eclipse.org/c/recommenders/org.eclipse.recommenders.git/snapshot/org.eclipse.recommenders-%{git_tag}.tar.xz

BuildArch:      noarch

# Allow building against newer versions of guava
Patch0:         guava-compat.patch

# Allow building against newer versions of lucene
Patch1:         lucene-compat.patch

BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(org.apache.maven.plugins:maven-clean-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-remote-resources-plugin)
BuildRequires:  mvn(org.eclipse.tycho.extras:tycho-eclipserun-plugin)
BuildRequires:  mvn(org.eclipse.tycho.extras:tycho-source-feature-plugin)
BuildRequires:  mvn(org.eclipse.tycho:target-platform-configuration)
BuildRequires:  mvn(org.eclipse.tycho:tycho-compiler-plugin)
BuildRequires:  mvn(org.eclipse.tycho:tycho-maven-plugin)
BuildRequires:  mvn(org.eclipse.tycho:tycho-p2-plugin)
BuildRequires:  mvn(org.eclipse.tycho:tycho-packaging-plugin)
BuildRequires:  mvn(org.eclipse.tycho:tycho-source-plugin)
BuildRequires:  mvn(org.osgi:osgi.annotation)

# OSGi BRs
BuildRequires:  eclipse-license
BuildRequires:  eclipse-egit
BuildRequires:  eclipse-m2e-core >= 1.8.3
BuildRequires:  eclipse-mylyn
BuildRequires:  eclipse-mylyn-context-java
BuildRequires:  apache-commons-codec
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-logging
BuildRequires:  apache-commons-math
BuildRequires:  apache-commons-pool
BuildRequires:  osgi(com.google.gson)
BuildRequires:  osgi(com.google.guava)
BuildRequires:  osgi(com.google.inject) >= 4.1-8
BuildRequires:  osgi(com.google.inject.multibindings) >= 4.1-8
BuildRequires:  cglib
BuildRequires:  objectweb-asm
BuildRequires:  lucene3
BuildRequires:  solr3 >= 3.6.2-17
# Use old names for aether due to supporting F26 still
BuildRequires:  aether-api
BuildRequires:  aether-connector-basic
BuildRequires:  aether-impl
BuildRequires:  aether-spi
BuildRequires:  aether-transport-file
BuildRequires:  aether-transport-http
BuildRequires:  aether-util

Requires:       eclipse-platform
BuildRequires:  osgi(com.google.inject) >= 4.1-8
BuildRequires:  osgi(com.google.inject.multibindings) >= 4.1-8
Requires:       cglib
Requires:       objectweb-asm
# Use old names for aether due to supporting F26 still
Requires:       aether-api
Requires:       aether-connector-basic
Requires:       aether-impl
Requires:       aether-spi
Requires:       aether-transport-file
Requires:       aether-transport-http
Requires:       aether-util

%description
Code Recommenders automatically analyzes existing code using APIs and extracts
common usage rules and patterns from it. In the form of recommendation models,
this knowledge is then fed back into your IDE. Code Recommenders’ intelligent
code completion and augmented API documentation then utilizes the power of
these models to provide you with the solutions implemented by other developers
in the past. This helps you to get up to speed with the new framework or API
without countless hours of searching the Internet for the solutions to common
problems.

%prep
%setup -q -n org.eclipse.recommenders-%{git_tag}
%patch0
%patch1

# Remove any pre-built binaries
find -name *.jar -delete
find -name *.class -delete

# Remove features that we don't need to ship
%pom_disable_module org.eclipse.recommenders.3rd.feature features

# No need to build update sites and target platforms for RPM builds
%pom_disable_module repositories
%pom_disable_module targets

# Remove use of tycho-sourceref-jgit (source is not a git repo)
%pom_remove_plugin org.eclipse.tycho:tycho-packaging-plugin
%pom_remove_plugin org.eclipse.tycho:target-platform-configuration

# Remove invokations of check plugins unnecessary for RPM builds
%pom_remove_plugin -r :animal-sniffer-maven-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :maven-jdeps-plugin
%pom_remove_plugin -r :maven-license-plugin
%pom_remove_plugin -r :tidy-maven-plugin

%if 0%{?fedora} == 26
# Bundles has a different BSN on older Fedoras
sed -i -e 's/org.apache.maven.resolver/org.eclipse.aether/' features/org.eclipse.recommenders.rcp.feature/feature.xml
%endif

# Relax dep on maven-resolver
sed -i -e '/aether/s/1\.1\.0/2.0.0/' plugins/org.eclipse.recommenders.models/META-INF/MANIFEST.MF

# Relax dep on guava and guice
sed -i -e '/com\.google\.common/s/;version="\[15.0.0,16.0.0)"/;version="[15.0.0,21.0.0)"/' $(find -name MANIFEST.MF)
sed -i -e '/com\.google\.inject/s/;bundle-version="\[3.0.0,4.0.0)"//' plugins/org.eclipse.recommenders.injection/META-INF/MANIFEST.MF
sed -i -e '/<import plugin="com/s/compatible/greaterOrEqual/' $(find features -name feature.xml)

# Fix dep on apache-commons-math -> apache-commons-math3
sed -i -e '/org.apache.commons.math/s/math/math3/;/org.apache.commons.math/s/2...0,3.0.0/3.0.0,4.0.0/' \
  plugins/org.eclipse.recommenders.jayes.transformation/META-INF/MANIFEST.MF \
  plugins/org.eclipse.recommenders.overrides/META-INF/MANIFEST.MF
sed -i -e '/import org.apache.commons.math/s/math/math3/' \
  plugins/org.eclipse.recommenders.jayes.transformation/src/org/eclipse/recommenders/jayes/transformation/*.java \
  plugins/org.eclipse.recommenders.overrides/src/org/eclipse/recommenders/overrides/*.java

# Use maven implementation from m2e
sed -i -e '/org.apache.maven.repository.internal/d' -e '/Require-Bundle/a\ org.eclipse.m2e.maven.runtime,' \
  plugins/org.eclipse.recommenders.models/META-INF/MANIFEST.MF
sed -i -e '/org.eclipse.aether.maven/d' features/org.eclipse.recommenders.rcp.feature/feature.xml

# Disable testing for now (requires xtext)
%pom_disable_module tests
%pom_disable_module org.eclipse.recommenders.testing.rcp.feature features
%pom_disable_module org.eclipse.recommenders.testing.rcp plugins
%pom_disable_module org.eclipse.recommenders.testing plugins
%pom_disable_module org.eclipse.recommenders.jayes.transformation plugins

# Don't install parent poms
%mvn_package "::pom::" __noinstall

%build
# Qualifier generated from last modification time of source tarball
QUALIFIER=$(date -u -d"$(stat --format=%y %{SOURCE0})" +v%Y%m%d-%H%M)
%mvn_build  -j -- -DforceContextQualifier=$QUALIFIER

%install
%mvn_install

%files -f .mfiles

%changelog
* Wed Mar 21 2018 Mat Booth <mat.booth@redhat.com> - 2.5.1-2
- Rebuild to regenerate symlinks

* Tue Mar 20 2018 Mat Booth <mat.booth@redhat.com> - 2.5.1-1
- Update to latest release

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Dec 17 2017 Mat Booth <mat.booth@redhat.com> - 2.5.0-1
- Update to Oxygen.2 release

* Mon Oct 02 2017 Mat Booth <mat.booth@redhat.com> - 2.4.10-3
- Simplify conditional

* Mon Oct 02 2017 Mat Booth <mat.booth@redhat.com> - 2.4.10-2
- Bump requirement on google-guice and rebuild to regenerate symlinks

* Sun Sep 17 2017 Mat Booth <mat.booth@redhat.com> - 2.4.10-1
- Update to Oxygen.1 release

* Mon Sep 04 2017 Mat Booth <mat.booth@redhat.com> - 2.4.9-2
- Fix build on F26
- Add dep on guice to fix dangling symlink

* Thu Aug 24 2017 Mat Booth <mat.booth@redhat.com> - 2.4.9-1
- Initial packaging

